@@ -48,7 +48,7 @@ class HistoricalPropertyEvents(str, Enum):
 
 class NamedEventBus(EventBusBase):
     def __init__(self, stream_name, kinesis=None, logger=None, ignore_custom_stages=True):
-        stage = get_properly_stage_for_resource(use_local=True, ignore_custom_stages=ignore_custom_stages)
+        stage = get_properly_stage_for_resource(use_local_for_tests=True, ignore_custom_stages=ignore_custom_stages)
         self.kinesis = kinesis or boto3.client("kinesis")
         self.stream_name = f"{stage}-{stream_name}"
         self.logger = logger if logger else ProperLogger("NamedEventBus")
